@@ -4,7 +4,7 @@ use warnings;
 use 5.006;
 
 package LWP::ConsoleLogger;
-$LWP::ConsoleLogger::VERSION = '0.000015';
+$LWP::ConsoleLogger::VERSION = '0.000016';
 use Data::Printer { end_separator => 1, hash_separator => ' => ' };
 use DateTime qw();
 use HTML::Restrict qw();
@@ -138,7 +138,7 @@ sub request_callback {
         $self->_log_params( $req, 'GET' );
     }
     else {
-        $self->_log_params( $req, $_ ) for ( 'GET', 'POST' );
+        $self->_log_params( $req, $_ ) for ( 'GET', $req->method );
     }
 
     $self->_log_headers( 'request', $req->headers );
@@ -183,14 +183,14 @@ sub _log_headers {
 }
 
 sub _log_params {
-    my ( $self, $req, $method ) = @_;
+    my ( $self, $req, $type ) = @_;
 
     return if !$self->dump_params;
 
     my %params;
     my $uri = $req->uri;
 
-    if ( $method eq 'GET' ) {
+    if ( $type eq 'GET' ) {
         my @params = $uri->query_param;
         return unless @params;
 
@@ -212,7 +212,7 @@ sub _log_params {
         $t->row( $name, $_ ) for sort @values;
     }
 
-    $self->_draw( $t, "$method Params:\n" );
+    $self->_draw( $t, "$type Params:\n" );
 }
 
 sub _log_cookies {
@@ -285,11 +285,11 @@ sub _log_content {
 
 sub _log_text {
     my $self         = shift;
-    my $ua           = shift;
+    my $res          = shift;
     my $content_type = shift;
 
     return unless $self->dump_text;
-    my $content = $self->_get_content( $ua, $content_type );
+    my $content = $self->_get_content( $res, $content_type );
     return unless $content;
 
     # If a pre_filter converts HTML to text, for example, we don't want to
@@ -297,7 +297,7 @@ sub _log_text {
 
     if ( $self->text_pre_filter ) {
         ( $content, my $type )
-            = $self->text_pre_filter->( $content, $content_type );
+            = $self->text_pre_filter->( $content, $content_type, $res->base );
         $content_type = $type if $type;
     }
 
@@ -374,7 +374,7 @@ LWP::ConsoleLogger - LWP tracing and debugging
 
 =head1 VERSION
 
-version 0.000015
+version 0.000016
 
 =head1 SYNOPSIS
 
@@ -616,6 +616,7 @@ text_pre_filter.
     sub {
         my $content      = shift;
         my $content_type = shift; # the value of the Content-Type header
+        my $base_url     = shift;
 
         # do something with the content
         # ...
@@ -658,8 +659,7 @@ parameter to constrain the tables to an arbitrary width.
 
 Aside from the BETA warnings, I should say that I've written this to suit my
 needs and there are a lot of things I haven't considered.  For example, I'm
-really only dealing with GET and POST. Also, I'm mostly assuming that the
-content will be text, HTML, JSON or XML.
+mostly assuming that the content will be text, HTML, JSON or XML.
 
 The test suite is not very robust either.  If you'd like to contribute to this
 module and you can't find an appropriate test, do add something to the example
